@@ -12,13 +12,14 @@
 
 from oslo_utils import timeutils
 import pecan
-from six.moves.urllib import parse
+from urllib import parse
 
 from barbican import api
 from barbican.api import controllers
 from barbican.api.controllers import acls
 from barbican.api.controllers import consumers
 from barbican.api.controllers import secretmeta
+from barbican.api.controllers import versions
 from barbican.common import accept
 from barbican.common import exception
 from barbican.common import hrefs
@@ -118,6 +119,9 @@ class SecretController(controllers.ACLMixin):
 
             LOG.info('Retrieved secret metadata for project: %s',
                      external_project_id)
+            if versions.is_supported(pecan.request, max_version='1.0'):
+                # NOTE(xek): consumers are being introduced in 1.1
+                del resp['consumers']
             return resp
         else:
             LOG.warning('Decrypted secret %s requested using deprecated '
@@ -360,8 +364,14 @@ class SecretsController(controllers.ACLMixin):
     @controllers.handle_exceptions(u._('Secret(s) retrieval'))
     @controllers.enforce_rbac('secrets:get')
     def on_get(self, external_project_id, **kw):
+        no_consumers = versions.is_supported(pecan.request, max_version='1.0')
+        # NOTE(xek): consumers are being introduced in 1.1
+
         def secret_fields(field):
-            return putil.mime_types.augment_fields_with_content_types(field)
+            resp = putil.mime_types.augment_fields_with_content_types(field)
+            if no_consumers:
+                del resp['consumers']
+            return resp
 
         LOG.debug('Start secrets on_get '
                   'for project-ID %s:', external_project_id)
@@ -388,7 +398,7 @@ class SecretsController(controllers.ACLMixin):
         ctxt = controllers._get_barbican_context(pecan.request)
         user_id = None
         if ctxt:
-            user_id = ctxt.user
+            user_id = ctxt.user_id
 
         result = self.secret_repo.get_secret_list(
             external_project_id,
@@ -445,7 +455,7 @@ class SecretsController(controllers.ACLMixin):
                                         'false').lower() == 'true'
         ctxt = controllers._get_barbican_context(pecan.request)
         if ctxt:  # in authenticated pipleline case, always use auth token user
-            data['creator_id'] = ctxt.user
+            data['creator_id'] = ctxt.user_id
 
         secret_model = models.Secret(data)
 
