@@ -71,10 +71,9 @@ def get_client(target=None, version_cap=None, serializer=None):
         return None
 
     queue_target = target or get_target()
-    return messaging.RPCClient(TRANSPORT,
-                               target=queue_target,
-                               version_cap=version_cap,
-                               serializer=serializer)
+    return messaging.get_rpc_client(
+        TRANSPORT, target=queue_target, version_cap=version_cap,
+        serializer=serializer)
 
 
 def get_server(target, endpoints, serializer=None):
@@ -106,10 +105,13 @@ def get_notification_server(targets, endpoints, serializer=None):
     """
     allow_requeue = getattr(getattr(CONF, KS_NOTIFICATIONS_GRP_NAME),
                             'allow_requeue')
+    pool_name = getattr(getattr(CONF, KS_NOTIFICATIONS_GRP_NAME),
+                        'pool_name')
     TRANSPORT._require_driver_features(requeue=allow_requeue)
     dispatcher = notify_dispatcher.NotificationDispatcher(endpoints,
                                                           serializer)
     # we don't want blocking executor so use eventlet as executor choice
     return listener.NotificationServer(TRANSPORT, targets, dispatcher,
                                        executor='eventlet',
+                                       pool=pool_name,
                                        allow_requeue=allow_requeue)
