@@ -13,14 +13,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import datetime
+from unittest import mock
+
+from oslo_db import exception as db_exc
+from sqlalchemy.exc import IntegrityError
+
 from barbican.model import clean
 from barbican.model import models
 from barbican.model import repositories as repos
 from barbican.tests import database_utils as utils
-from sqlalchemy.exc import IntegrityError
-
-import datetime
-import mock
 
 
 def _create_project(project_name):
@@ -67,9 +69,6 @@ def _setup_entry(name, *args, **kwargs):
 
 class WhenTestingDBCleanUpCommand(utils.RepositoryTestCase):
 
-    def setUp(self):
-        super(WhenTestingDBCleanUpCommand, self).setUp()
-
     def tearDown(self):
         super(WhenTestingDBCleanUpCommand, self).tearDown()
         repos.rollback()
@@ -336,7 +335,8 @@ class WhenTestingDBCleanUpCommand(utils.RepositoryTestCase):
         self.assertFalse(_entry_exists(childless_project))
 
         container.delete()
-        map(lambda child: child.delete(), project_children_list)
+        for child in project_children_list:
+            child.delete()
         clean.cleanup_all()
         clean.cleanup_unassociated_projects()
         self.assertFalse(_entry_exists(project_with_children))
@@ -363,11 +363,11 @@ class WhenTestingDBCleanUpCommand(utils.RepositoryTestCase):
                             test_log_file)
         set_calls = [mock.call('debug', True),
                      mock.call('log_file', test_log_file),
-                     mock.call('sql_connection', test_sql_url)]
+                     mock.call('connection', test_sql_url, 'database')]
         mock_conf.set_override.assert_has_calls(set_calls)
 
         clear_calls = [mock.call('debug'), mock.call('log_file'),
-                       mock.call('sql_connection')]
+                       mock.call('connection', 'database')]
         mock_conf.clear_override.assert_has_calls(clear_calls)
         self.assertTrue(mock_repo.setup_database_engine_and_factory.called)
         self.assertTrue(mock_repo.commit.called)
@@ -433,4 +433,4 @@ class WhenTestingDBCleanUpCommand(utils.RepositoryTestCase):
         secret.deleted = True
         secret_metadatum.deleted = False
 
-        self.assertRaises(IntegrityError, clean.cleanup_all)
+        self.assertRaises(db_exc.DBReferenceError, clean.cleanup_all)
