@@ -17,11 +17,9 @@ import datetime
 import unittest
 
 from oslo_serialization import base64
-import testtools
 
 from barbican.common import exception as excep
 from barbican.common import validators
-from barbican.tests import certificate_utils as certs
 from barbican.tests import keys
 from barbican.tests import utils
 
@@ -1191,11 +1189,6 @@ class WhenTestingKeyTypeOrderValidator(utils.BaseTestCase):
 
         self.validator = validators.TypeOrderValidator()
 
-    def test_should_pass_with_certificate_type_in_order_refs(self):
-        self.key_order_req['type'] = 'certificate'
-        result = self.validator.validate(self.key_order_req)
-        self.assertEqual('certificate', result['type'])
-
     def test_should_pass_with_null_content_type_in_meta(self):
         self.key_order_req['meta']['payload_content_type'] = None
         result = self.validator.validate(self.key_order_req)
@@ -1365,238 +1358,6 @@ class WhenTestingAsymmetricTypeOrderValidator(utils.BaseTestCase):
         self.assertEqual("bit_length", exception.invalid_property)
 
 
-class WhenTestingSimpleCMCOrderValidator(utils.BaseTestCase):
-
-    def setUp(self):
-        super(WhenTestingSimpleCMCOrderValidator, self).setUp()
-        self.type = 'certificate'
-        request_data = base64.encode_as_text(certs.create_good_csr())
-        self.meta = {'request_type': 'simple-cmc',
-                     'request_data': request_data,
-                     'requestor_name': 'Barbican User',
-                     'requestor_email': 'barbican_user@example.com',
-                     'requestor_phone': '555-1212'}
-        self._set_order()
-        self.validator = validators.TypeOrderValidator()
-
-    def _set_order(self):
-        self.order_req = {'type': self.type,
-                          'meta': self.meta}
-
-    def test_should_pass_good_data(self):
-        self.validator.validate(self.order_req)
-
-    def test_should_raise_with_no_metadata(self):
-        self.order_req = {'type': self.type}
-        self.assertRaises(excep.InvalidObject,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_raise_with_bad_request_type(self):
-        self.meta['request_type'] = 'bad_request_type'
-        self._set_order()
-        self.assertRaises(excep.InvalidCertificateRequestType,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_raise_with_no_request_data(self):
-        del self.meta['request_data']
-        self._set_order()
-        self.assertRaises(excep.MissingMetadataField,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_raise_with_pkcs10_data_with_bad_base64(self):
-        self.meta['request_data'] = certs.create_bad_csr()
-        self._set_order()
-        self.assertRaises(excep.PayloadDecodingError,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_raise_with_bad_pkcs10_data(self):
-        request_data = base64.encode_as_text(certs.create_bad_csr())
-        self.meta['request_data'] = request_data
-        self._set_order()
-        self.assertRaises(excep.InvalidPKCS10Data,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_raise_with_signed_wrong_key_pkcs10_data(self):
-        self.meta['request_data'] = base64.encode_as_text(
-            certs.create_csr_signed_with_wrong_key())
-        self._set_order()
-        self.assertRaises(excep.InvalidPKCS10Data,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_raise_with_unsigned_pkcs10_data(self):
-        self.meta['request_data'] = base64.encode_as_text(
-            certs.create_csr_that_has_not_been_signed())
-        self._set_order()
-        self.assertRaises(excep.InvalidPKCS10Data,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_raise_with_payload_in_order(self):
-        self.meta['payload'] = 'payload'
-        self.assertRaises(excep.InvalidObject,
-                          self.validator.validate,
-                          self.order_req)
-
-
-class WhenTestingFullCMCOrderValidator(utils.BaseTestCase):
-
-    def setUp(self):
-        super(WhenTestingFullCMCOrderValidator, self).setUp()
-        self.type = 'certificate'
-        self.meta = {'request_type': 'full-cmc',
-                     'request_data': VALID_FULL_CMC,
-                     'requestor_name': 'Barbican User',
-                     'requestor_email': 'barbican_user@example.com',
-                     'requestor_phone': '555-1212'}
-        self._set_order()
-        self.validator = validators.TypeOrderValidator()
-
-    def _set_order(self):
-        self.order_req = {'type': self.type,
-                          'meta': self.meta}
-
-    def test_should_raise_not_yet_implemented(self):
-        self.assertRaises(excep.FullCMCNotSupported,
-                          self.validator.validate,
-                          self.order_req)
-
-    @testtools.skip("Feature not yet implemented")
-    def test_should_pass_good_data(self):
-        self.validator.validate(self.order_req)
-
-    @testtools.skip("Feature not yet implemented")
-    def test_should_raise_with_no_request_data(self):
-        del self.meta['request_data']
-        self._set_order()
-        self.assertRaises(excep.MissingMetadataField,
-                          self.validator.validate,
-                          self.order_req)
-
-    @testtools.skip("Not yet implemented")
-    def test_should_raise_with_bad_cmc_data(self):
-        self.meta['request_data'] = 'Bad CMC Data'
-        self._set_order()
-        self.assertRaises(excep.InvalidCMCData,
-                          self.validator.validate,
-                          self.order_req)
-
-
-class WhenTestingCustomOrderValidator(utils.BaseTestCase):
-
-    def setUp(self):
-        super(WhenTestingCustomOrderValidator, self).setUp()
-        self.type = 'certificate'
-        self.meta = {'request_type': 'custom',
-                     'ca_param_1': 'value_1',
-                     'ca_param_2': 'value_2',
-                     'requestor_name': 'Barbican User',
-                     'requestor_email': 'barbican_user@example.com',
-                     'requestor_phone': '555-1212'}
-        self._set_order()
-        self.validator = validators.TypeOrderValidator()
-
-    def _set_order(self):
-        self.order_req = {'type': self.type,
-                          'meta': self.meta}
-
-    def test_should_pass_good_data(self):
-        self.validator.validate(self.order_req)
-
-    def test_should_pass_with_no_request_type(self):
-        # defaults to custom
-        del self.meta['request_type']
-        self._set_order()
-        self.validator.validate(self.order_req)
-
-
-class WhenTestingStoredKeyOrderValidator(utils.BaseTestCase):
-
-    def setUp(self):
-        super(WhenTestingStoredKeyOrderValidator, self).setUp()
-        self.type = 'certificate'
-        self.meta = {'request_type': 'stored-key',
-                     'container_ref':
-                         'https://localhost/v1/containers/good_container_ref',
-                     'subject_dn': 'cn=barbican-server,o=example.com',
-                     'requestor_name': 'Barbican User',
-                     'requestor_email': 'barbican_user@example.com',
-                     'requestor_phone': '555-1212'}
-        self.order_req = {'type': self.type,
-                          'meta': self.meta}
-        self.validator = validators.TypeOrderValidator()
-
-    def test_should_pass_good_data(self):
-        self.validator.validate(self.order_req)
-
-    def test_should_raise_with_no_container_ref(self):
-        del self.meta['container_ref']
-        self.assertRaises(excep.MissingMetadataField,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_raise_with_no_subject_dn(self):
-        del self.meta['subject_dn']
-        self.assertRaises(excep.MissingMetadataField,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_pass_with_profile_and_ca_id(self):
-        self.meta['ca_id'] = 'my_ca_id'
-        self.meta['profile'] = 'my_profile'
-        self.validator.validate(self.order_req)
-
-    def test_should_raise_with_profile_and_no_ca_id(self):
-        self.meta['profile'] = 'my_profile'
-        self.assertRaises(excep.MissingMetadataField,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_raise_with_extensions_data(self):
-        self.meta['extensions'] = VALID_EXTENSIONS
-        self.assertRaises(excep.CertificateExtensionsNotSupported,
-                          self.validator.validate,
-                          self.order_req)
-
-    @testtools.skip("Not yet implemented")
-    def test_should_raise_with_bad_extensions_data(self):
-        self.meta['extensions'] = 'Bad extensions data'
-        self.assertRaises(excep.InvalidExtensionsData,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_pass_with_one_cn_in_dn(self):
-        self.meta['subject_dn'] = "CN=example1"
-        self.validator.validate(self.order_req)
-
-    def test_should_pass_with_two_cn_in_dn(self):
-        self.meta['subject_dn'] = "CN=example1,CN=example2"
-        self.validator.validate(self.order_req)
-
-    def test_should_raise_with_blank_dn(self):
-        self.meta['subject_dn'] = ""
-        self.assertRaises(excep.InvalidSubjectDN,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_raise_with_bad_subject_dn(self):
-        self.meta['subject_dn'] = "Bad subject DN data"
-        self.assertRaises(excep.InvalidSubjectDN,
-                          self.validator.validate,
-                          self.order_req)
-
-    def test_should_raise_with_payload_in_order(self):
-        self.meta['payload'] = 'payload'
-        self.assertRaises(excep.InvalidObject,
-                          self.validator.validate,
-                          self.order_req)
-
-
 @utils.parameterized_test_case
 class WhenTestingAclValidator(utils.BaseTestCase):
     def setUp(self):
