@@ -15,19 +15,17 @@
 
 from unittest import mock
 
-import six
-
 from barbican.common import utils as common_utils
 from barbican.plugin.crypto import base
 from barbican.plugin.crypto import manager as cm
 from barbican.plugin.crypto import p11_crypto
-from barbican.plugin.interface import secret_store as str
+from barbican.plugin.interface import secret_store as ss
 from barbican.plugin import kmip_secret_store as kss
 from barbican.plugin import store_crypto
 from barbican.tests import utils
 
 
-class TestSecretStore(str.SecretStoreBase):
+class TestSecretStore(ss.SecretStoreBase):
     """Secret store plugin for testing support."""
 
     def __init__(self, supported_alg_list):
@@ -59,7 +57,7 @@ class TestSecretStore(str.SecretStoreBase):
         return key_spec.alg in self.alg_list
 
 
-class TestSecretStoreWithTransportKey(str.SecretStoreBase):
+class TestSecretStoreWithTransportKey(ss.SecretStoreBase):
     """Secret store plugin for testing support.
 
     This plugin will override the relevant methods for key wrapping.
@@ -104,19 +102,19 @@ class WhenTestingSecretStorePluginManager(utils.BaseTestCase):
 
     def setUp(self):
         super(WhenTestingSecretStorePluginManager, self).setUp()
-        self.manager = str.SecretStorePluginManager()
+        self.manager = ss.SecretStorePluginManager()
 
     def test_get_store_supported_plugin_no_plugin_name(self):
-        plugin = TestSecretStore([str.KeyAlgorithm.AES])
+        plugin = TestSecretStore([ss.KeyAlgorithm.AES])
         plugin_mock = mock.MagicMock(obj=plugin)
         self.manager.extensions = [plugin_mock]
-        keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+        keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
 
         self.assertEqual(plugin,
                          self.manager.get_plugin_store(keySpec))
 
     def test_get_store_supported_plugin_with_plugin_name(self):
-        plugin = TestSecretStore([str.KeyAlgorithm.AES])
+        plugin = TestSecretStore([ss.KeyAlgorithm.AES])
         plugin_mock = mock.MagicMock(obj=plugin)
         self.manager.extensions = [plugin_mock]
 
@@ -125,33 +123,33 @@ class WhenTestingSecretStorePluginManager(utils.BaseTestCase):
         self.assertEqual(plugin, plugin_found)
 
     def test_get_generate_supported_plugin(self):
-        plugin = TestSecretStore([str.KeyAlgorithm.AES])
+        plugin = TestSecretStore([ss.KeyAlgorithm.AES])
         plugin_mock = mock.MagicMock(obj=plugin)
         self.manager.extensions = [plugin_mock]
-        keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+        keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
 
         self.assertEqual(plugin,
                          self.manager.get_plugin_generate(keySpec))
 
     def test_get_store_no_plugin_found(self):
         self.manager.extensions = []
-        keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+        keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
         self.assertRaises(
-            str.SecretStorePluginsNotConfigured,
+            ss.SecretStorePluginsNotConfigured,
             self.manager.get_plugin_store,
             keySpec,
         )
 
     def test_get_store_no_plugin_found_by_name(self):
-        plugin = TestSecretStore([str.KeyAlgorithm.AES])
+        plugin = TestSecretStore([ss.KeyAlgorithm.AES])
         plugin_mock = mock.MagicMock(obj=plugin)
         self.manager.extensions = [plugin_mock]
 
-        keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+        keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
         plugin_name = 'plugin'
 
         exception_result = self.assertRaises(
-            str.SecretStorePluginNotFound,
+            ss.SecretStorePluginNotFound,
             self.manager.get_plugin_store,
             keySpec,
             plugin_name=plugin_name
@@ -159,13 +157,13 @@ class WhenTestingSecretStorePluginManager(utils.BaseTestCase):
 
         self.assertEqual(
             'Secret store plugin "{name}" not found.'.format(name=plugin_name),
-            six.text_type(exception_result))
+            str(exception_result))
 
     def test_get_generate_no_plugin_found(self):
         self.manager.extensions = []
-        keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+        keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
         self.assertRaises(
-            str.SecretStorePluginsNotConfigured,
+            ss.SecretStorePluginsNotConfigured,
             self.manager.get_plugin_generate,
             keySpec,
         )
@@ -174,9 +172,9 @@ class WhenTestingSecretStorePluginManager(utils.BaseTestCase):
         plugin = TestSecretStore([])
         plugin_mock = mock.MagicMock(obj=plugin)
         self.manager.extensions = [plugin_mock]
-        keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+        keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
         self.assertRaises(
-            str.SecretStoreSupportedPluginNotFound,
+            ss.SecretStoreSupportedPluginNotFound,
             self.manager.get_plugin_store,
             keySpec,
         )
@@ -185,9 +183,9 @@ class WhenTestingSecretStorePluginManager(utils.BaseTestCase):
         plugin = TestSecretStore([])
         plugin_mock = mock.MagicMock(obj=plugin)
         self.manager.extensions = [plugin_mock]
-        keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+        keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
         self.assertRaises(
-            str.SecretGenerateSupportedPluginNotFound,
+            ss.SecretGenerateSupportedPluginNotFound,
             self.manager.get_plugin_generate,
             keySpec,
         )
@@ -196,9 +194,9 @@ class WhenTestingSecretStorePluginManager(utils.BaseTestCase):
         plugin = TestSecretStore([])
         plugin_mock = mock.MagicMock(obj=plugin)
         self.manager.extensions = [plugin_mock]
-        keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+        keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
         self.assertRaises(
-            str.SecretStoreSupportedPluginNotFound,
+            ss.SecretStoreSupportedPluginNotFound,
             self.manager.get_plugin_store,
             key_spec=keySpec,
             transport_key_needed=True,
@@ -208,21 +206,21 @@ class WhenTestingSecretStorePluginManager(utils.BaseTestCase):
         plugin = TestSecretStoreWithTransportKey([])
         plugin_mock = mock.MagicMock(obj=plugin)
         self.manager.extensions = [plugin_mock]
-        keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+        keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
         self.assertRaises(
-            str.SecretStoreSupportedPluginNotFound,
+            ss.SecretStoreSupportedPluginNotFound,
             self.manager.get_plugin_store,
             key_spec=keySpec,
             transport_key_needed=True,
         )
 
     def test_get_store_plugin_with_no_tkey_and_supports_storage(self):
-        plugin = TestSecretStore([str.KeyAlgorithm.AES])
+        plugin = TestSecretStore([ss.KeyAlgorithm.AES])
         plugin_mock = mock.MagicMock(obj=plugin)
         self.manager.extensions = [plugin_mock]
-        keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+        keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
         self.assertRaises(
-            str.SecretStoreSupportedPluginNotFound,
+            ss.SecretStoreSupportedPluginNotFound,
             self.manager.get_plugin_store,
             key_spec=keySpec,
             transport_key_needed=True,
@@ -231,7 +229,7 @@ class WhenTestingSecretStorePluginManager(utils.BaseTestCase):
     @mock.patch('barbican.common.utils.generate_fullname_for')
     def test_get_retrieve_plugin_raises_when_not_available(
             self, generate_full_name_for):
-        plugin = TestSecretStore([str.KeyAlgorithm.AES])
+        plugin = TestSecretStore([ss.KeyAlgorithm.AES])
         plugin_mock = mock.MagicMock(obj=plugin)
         self.manager.extensions = [plugin_mock]
 
@@ -239,19 +237,19 @@ class WhenTestingSecretStorePluginManager(utils.BaseTestCase):
         plugin_name = 'plugin name searched for'
 
         exception_result = self.assertRaises(
-            str.StorePluginNotAvailableOrMisconfigured,
+            ss.StorePluginNotAvailableOrMisconfigured,
             self.manager.get_plugin_retrieve_delete,
             plugin_name=plugin_name,
         )
-        self.assertIn(plugin_name, six.text_type(exception_result))
+        self.assertIn(plugin_name, str(exception_result))
 
     def test_get_store_plugin_with_tkey_and_supports_storage(self):
-        plugin1 = TestSecretStore([str.KeyAlgorithm.AES])
+        plugin1 = TestSecretStore([ss.KeyAlgorithm.AES])
         plugin1_mock = mock.MagicMock(obj=plugin1)
-        plugin2 = TestSecretStoreWithTransportKey([str.KeyAlgorithm.AES])
+        plugin2 = TestSecretStoreWithTransportKey([ss.KeyAlgorithm.AES])
         plugin2_mock = mock.MagicMock(obj=plugin2)
         self.manager.extensions = [plugin1_mock, plugin2_mock]
-        keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+        keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
         self.assertEqual(plugin2,
                          self.manager.get_plugin_store(
                              key_spec=keySpec,
@@ -274,13 +272,17 @@ class TestSecretStorePluginManagerMultipleBackend(
                         '_create_pkcs11') as m_pkcs11, \
                 mock.patch('kmip.pie.client.ProxyKmipClient') as m_kmip:
 
-            manager = str.SecretStorePluginManager()
+            manager = ss.SecretStorePluginManager()
 
             # check pkcs11 and kmip plugin instantiation call is invoked
-            m_pkcs11.called_once_with(mock.ANY, mock.ANY)
-            m_kmip.called_once_with(mock.ANY)
+            m_pkcs11.assert_called_once_with(None)
+            m_kmip.assert_called_once_with(hostname='localhost', port=5696,
+                                           cert=None, key=None, ca=None,
+                                           ssl_version='PROTOCOL_TLSv1_2',
+                                           username='sample_username',
+                                           password='sample_password')
             # check store crypto adapter is matched as its defined first.
-            keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+            keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
             plugin_found = manager.get_plugin_store(keySpec)
             self.assertIsInstance(plugin_found,
                                   store_crypto.StoreCryptoAdapterPlugin)
@@ -307,12 +309,16 @@ class TestSecretStorePluginManagerMultipleBackend(
                         '_create_pkcs11') as m_pkcs11, \
                 mock.patch('kmip.pie.client.ProxyKmipClient') as m_kmip:
 
-            manager = str.SecretStorePluginManager()
+            manager = ss.SecretStorePluginManager()
 
             # check pkcs11 and kmip plugin instantiation call is invoked
-            m_pkcs11.called_once_with(mock.ANY, mock.ANY)
-            m_kmip.called_once_with(mock.ANY)
+            m_pkcs11.assert_called_once_with(None)
+            m_kmip.assert_called_once_with(hostname='localhost', port=5696,
+                                           cert=None, key=None, ca=None,
+                                           ssl_version='PROTOCOL_TLSv1_2',
+                                           username='sample_username',
+                                           password='sample_password')
             # check kmip store is matched as its global default store.
-            keySpec = str.KeySpec(str.KeyAlgorithm.AES, 128)
+            keySpec = ss.KeySpec(ss.KeyAlgorithm.AES, 128)
             plugin_found = manager.get_plugin_store(keySpec)
             self.assertIsInstance(plugin_found, kss.KMIPSecretStore)
