@@ -38,6 +38,7 @@ from barbican.plugin.crypto import p11_crypto
 from barbican.plugin.interface import secret_store
 from barbican.plugin import kmip_secret_store as kss
 from barbican.tests import database_utils
+from barbican.tests import fixture as barbican_fixture
 
 
 def mock_pecan_request(test_instance, host=None, version='1.0'):
@@ -60,11 +61,13 @@ class BarbicanAPIBaseTestCase(oslotest.BaseTestCase):
     """Base TestCase for all tests needing to interact with a Barbican app."""
     root_controller = None
 
-    def _build_context(self, project_id, roles=None, user=None, is_admin=True,
-                       policy_enforcer=None):
+    def _build_context(
+        self, project_id, roles=None, user_id=None, is_admin=True,
+        policy_enforcer=None,
+    ):
         context = barbican.context.RequestContext(
             roles=roles,
-            user=user,
+            user_id=user_id,
             project_id=project_id,
             is_admin=is_admin
         )
@@ -72,7 +75,9 @@ class BarbicanAPIBaseTestCase(oslotest.BaseTestCase):
         return context
 
     def setUp(self):
-        super(BarbicanAPIBaseTestCase, self).setUp()
+        super().setUp()
+        self.useFixture(barbican_fixture.StandardLogging())
+        self.useFixture(barbican_fixture.WarningsFixture())
         # Make sure we have a test db and session to work with
         database_utils.setup_in_memory_db()
 
@@ -92,22 +97,23 @@ class BarbicanAPIBaseTestCase(oslotest.BaseTestCase):
 
     def tearDown(self):
         database_utils.in_memory_cleanup()
-        super(BarbicanAPIBaseTestCase, self).tearDown()
+        super().tearDown()
 
 
 class BaseTestCase(oslotest.BaseTestCase):
-    """DEPRECATED - Will remove in future refactoring."""
     def setUp(self):
-        super(BaseTestCase, self).setUp()
+        super().setUp()
+        self.useFixture(barbican_fixture.StandardLogging())
+        self.useFixture(barbican_fixture.WarningsFixture())
         self.order_id = 'order1234'
         self.external_project_id = 'keystone1234'
         self.request_id = 'request1234'
 
     def tearDown(self):
-        super(BaseTestCase, self).tearDown()
         ss_conf = config.get_module_config('secretstore')
         ss_conf.clear_override("enable_multiple_secret_stores",
                                group='secretstore')
+        super().tearDown()
 
 
 class MockModelRepositoryMixin(object):
